@@ -29,6 +29,7 @@ from pygeofilter.ast import AstType
 from tipg import model
 from tipg.collections import Catalog, Collection
 from tipg.dependencies import (
+    CatalogParams,
     CollectionParams,
     ItemsOutputType,
     OutputType,
@@ -42,12 +43,7 @@ from tipg.dependencies import (
     properties_query,
     sortby_query,
 )
-from tipg.errors import (
-    MissingCollectionCatalog,
-    MissingGeometryColumn,
-    NoPrimaryKey,
-    NotFound,
-)
+from tipg.errors import MissingGeometryColumn, NoPrimaryKey, NotFound
 from tipg.resources.enums import MediaType
 from tipg.resources.response import GeoJSONResponse, SchemaJSONResponse
 from tipg.settings import FeaturesSettings, MVTSettings, TMSSettings
@@ -193,6 +189,7 @@ class EndpointsFactory(metaclass=abc.ABCMeta):
     router: APIRouter = field(default_factory=APIRouter)
 
     # collection dependency
+    catalog_dependency: Callable[..., Catalog] = CatalogParams
     collection_dependency: Callable[..., Collection] = CollectionParams
 
     # Router Prefix is needed to find the path for routes when prefixed
@@ -439,10 +436,14 @@ class OGCFeaturesFactory(EndpointsFactory):
                 },
             },
         )
-        def collections(
+        def collections(  # noqa: C901
             request: Request,
             bbox_filter: Annotated[Optional[List[float]], Depends(bbox_query)],
             datetime_filter: Annotated[Optional[List[str]], Depends(datetime_query)],
+            type_filter: Annotated[
+                Optional[Literal["Function", "Table"]],
+                Query(alias="type", description="Filter based on Collection type."),
+            ] = None,
             limit: Annotated[
                 Optional[int],
                 Query(
@@ -459,19 +460,22 @@ class OGCFeaturesFactory(EndpointsFactory):
                 ),
             ] = None,
             output_type: Annotated[Optional[MediaType], Depends(OutputType)] = None,
+            collection_catalog=Depends(self.catalog_dependency),
         ):
             """List of collections."""
-            collection_catalog: Catalog = getattr(
-                request.app.state, "collection_catalog", None
-            )
-            if not collection_catalog:
-                raise MissingCollectionCatalog("Could not find collections catalog.")
-
             collections_list = list(collection_catalog["collections"].values())
 
             limit = limit or 0
             offset = offset or 0
 
+            # type filter
+            if type_filter is not None:
+                collections_list = [
+                    collection
+                    for collection in collections_list
+                    if collection.type == type_filter
+                ]
+
             # bbox filter
             if bbox_filter is not None:
                 collections_list = [
